@@ -258,8 +258,6 @@ class TonlibClient:
         r = await self.tonlib_wrapper.execute(request)
         if 'stack' in r:
             r['stack'] = serialize_tvm_stack(r['stack'])
-        if '@type' in r and r['@type'] == 'smc.runResult':
-            r.pop('@type')
         return r
 
     async def raw_send_message(self, serialized_boc, *args, **kwargs):
@@ -384,9 +382,7 @@ class TonlibClient:
             from_transaction_hash = hash_to_hex(from_transaction_hash)
         if (from_transaction_lt == None) or (from_transaction_hash == None):
             addr = await self.raw_get_account_state(account)
-            if '@type' in addr and addr['@type'] == "error":
-                addr = await self.raw_get_account_state(account)
-            if '@type' in addr and addr['@type'] == "error":
+            if addr.get('@type', 'error') == "error":
                 raise TonLibWrongResult("raw.getAccountState failed", addr)
             try:
                 from_transaction_lt, from_transaction_hash = int(
@@ -399,13 +395,10 @@ class TonlibClient:
         current_lt, curret_hash = from_transaction_lt, from_transaction_hash
         while (not reach_lt) and (len(all_transactions) < limit):
             raw_transactions = await self.raw_get_transactions(account, current_lt, curret_hash)
-            if(raw_transactions['@type']) == 'error':
-                break
-                # TODO probably we should chenge get_transactions API
-                # if 'message' in raw_transactions['message']:
-                #  raise Exception(raw_transactions['message'])
-                # else:
-                #  raise Exception("Can't get transactions")
+            if raw_transactions.get('@type', 'error') == 'error':
+                error_message = raw_transactions.get('message', '')
+                raise TonLibWrongResult(f"Couldn't get next transactions chunk: {error_message}", raw_transactions)
+
             transactions, next = raw_transactions['transactions'], raw_transactions.get(
                 "previous_transaction_id", None)
             for t in transactions:
@@ -547,9 +540,7 @@ class TonlibClient:
 
         while incomplete:
             result = await self.raw_get_block_transactions(fullblock, count, after_tx)
-            if(result['@type']) == 'error':
-                result = await self.raw_get_block_transactions(fullblock, count, after_tx)
-            if(result['@type']) == 'error':
+            if result.get('@type', 'error') == 'error':
                 raise TonLibWrongResult('Can\'t get blockTransactions', result)
             if not total_result:
                 total_result = result
@@ -603,9 +594,7 @@ class TonlibClient:
 
         while incomplete:
             result = await self.raw_get_block_transactions_ext(fullblock, count, after_tx)
-            if(result['@type']) == 'error':
-                result = await self.raw_get_block_transactions_ext(fullblock, count, after_tx)
-            if(result['@type']) == 'error':
+            if result.get('@type', 'error') == 'error':
                 raise TonLibWrongResult('Can\'t get blockTransactions', result)
             if not total_result:
                 total_result = result
